==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebGridToolbarTitleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridToolbarContentDescriptionMetadata } from "./WebGridToolbarContentDescriptionMetadata";
import { WebGridToolbarTitleDescription } from "./WebGridToolbarTitleDescription";
/**
 * @hidden
 */
export let WebGridToolbarTitleDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridToolbarTitleDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridToolbarTitleDescriptionMetadata.a == null) {
                WebGridToolbarTitleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridToolbarTitleDescriptionMetadata.c(WebGridToolbarTitleDescriptionMetadata.a);
            }
            if (a.k(WebGridToolbarTitleDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebGridToolbarTitleDescriptionMetadata.a);
        }
        static c(a) {
            WebGridToolbarContentDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GridToolbarTitle");
            a.item("__tagNameWC", "String:igc-grid-toolbar-title");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__portalChildrenWC", "Boolean");
            a.item("Name", "String");
            WebGridToolbarTitleDescriptionMetadata.e(a);
        }
        static d(a) {
            WebGridToolbarTitleDescriptionMetadata.b(a);
            a.ad("WebGridToolbarTitle", () => new WebGridToolbarTitleDescription());
            a.ac("WebGridToolbarTitle", WebGridToolbarTitleDescriptionMetadata.a);
        }
        static e(a) {
            a.item("__portalChildrenWC", "Boolean");
        }
    }
    WebGridToolbarTitleDescriptionMetadata.$t = markType(WebGridToolbarTitleDescriptionMetadata, 'WebGridToolbarTitleDescriptionMetadata');
    WebGridToolbarTitleDescriptionMetadata.a = null;
    return WebGridToolbarTitleDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebGridToolbarTitleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridToolbarContentDescriptionMetadata } from "./WebGridToolbarContentDescriptionMetadata";
import { WebGridToolbarTitleDescription } from "./WebGridToolbarTitleDescription";
/**
 * @hidden
 */
export let WebGridToolbarTitleDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridToolbarTitleDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridToolbarTitleDescriptionMetadata.a == null) {
                WebGridToolbarTitleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridToolbarTitleDescriptionMetadata.c(WebGridToolbarTitleDescriptionMetadata.a);
            }
            if (a.k(WebGridToolbarTitleDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebGridToolbarTitleDescriptionMetadata.a);
        }
        static c(a) {
            WebGridToolbarContentDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GridToolbarTitle");
            a.item("__tagNameWC", "String:igc-grid-toolbar-title");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__portalChildrenWC", "Boolean");
            a.item("Name", "String");
            WebGridToolbarTitleDescriptionMetadata.e(a);
        }
        static d(a) {
            WebGridToolbarTitleDescriptionMetadata.b(a);
            a.ae("WebGridToolbarTitle", () => new WebGridToolbarTitleDescription());
            a.ad("WebGridToolbarTitle", WebGridToolbarTitleDescriptionMetadata.a);
        }
        static e(a) {
            a.item("__portalChildrenWC", "Boolean");
        }
    }
    WebGridToolbarTitleDescriptionMetadata.$t = markType(WebGridToolbarTitleDescriptionMetadata, 'WebGridToolbarTitleDescriptionMetadata');
    WebGridToolbarTitleDescriptionMetadata.a = null;
    return WebGridToolbarTitleDescriptionMetadata;
})();
